@@ -2,8 +2,8 @@ import os
 import shutil
 import unittest
 
-from anchorage import anchor_locally, load, path, add_local as add, server
-from anchor_tools.local import setup, init
+from anchorage import add_local as add, server
+from anchorage.anchor_tools.local import setup, init
 
 
 class Tests(unittest.TestCase):
